@@ -1,7 +1,12 @@
-package SVN::Hooks::DenyFilenames;
-
 use strict;
 use warnings;
+
+package SVN::Hooks::DenyFilenames;
+{
+  $SVN::Hooks::DenyFilenames::VERSION = '1.12';
+}
+# ABSTRACT: Deny some file names.
+
 use Carp;
 use SVN::Hooks;
 
@@ -9,50 +14,6 @@ use Exporter qw/import/;
 my $HOOK = 'DENY_FILENAMES';
 our @EXPORT = ($HOOK, 'DENY_FILENAMES_PER_PATH');
 
-our $VERSION = $SVN::Hooks::VERSION;
-
-=head1 NAME
-
-SVN::Hooks::DenyFilenames - Deny some file names.
-
-=head1 SYNOPSIS
-
-This SVN::Hooks plugin is used to disallow the addition of some file
-names.
-
-It's active in the C<pre-commit> hook.
-
-It's configured by the following directives.
-
-=head2 DENY_FILENAMES(REGEXP, [REGEXP => MESSAGE], ...)
-
-This directive denies the addition of new files matching the Regexps
-passed as arguments. If any file or directory added in the commit
-matches one of the specified Regexps the commit is aborted with an
-error message telling about every denied file.
-
-The arguments may be compiled Regexps or two-element arrays consisting
-of a compiled Regexp and a specific error message. If a file matches
-one of the lone Regexps an error message like this is produced:
-
-        DENY_FILENAMES: filename not allowed: filename
-
-If a file matches a Regexp associated with an error message, the
-specified error message is substituted for the 'filename not allowed'
-default.
-
-Note that this directive specifies a default restriction. If there are
-any B<DENY_FILENAMES_PER_PATH> directives (see below) being used, this
-one is only used for files that don't match any specific rules there.
-
-Example:
-
-        DENY_FILENAMES(
-            qr/\.(doc|xls|ppt)$/i, # ODF only, please
-            [qr/\.(exe|zip|jar)/i => 'No binaries, please!'],
-        );
-
-=cut
 
 sub _grok_check {
     my ($directive, $check) = @_;
@@ -83,34 +44,6 @@ sub DENY_FILENAMES {
     return 1;
 }
 
-=head2 DENY_FILENAMES_PER_PATH(REGEXP => REGEXP, REGEXP => [REGEXP => MESSAGE], ...)
-
-This directive is more specific than the B<DENY_FILENAMES>, because it
-allows one to specify different restrictions in different regions of
-the repository tree.
-
-Its arguments are a sequence of rules, each one consisting of a
-pair. The first element of each pair is a regular expression
-specifying where in the repository this rule applies. It applies if
-any file being added matches the regexp. The second element specifies
-the restrictions that should be imposed, just like the arguments to
-B<DENY_FILENAMES>.
-
-The first rule matching an added file is used to check it. The
-following rules aren't tried.
-
-Only if no rules match a particular file will the restrictions defined
-by B<DENY_FILENAMES> be imposed.
-
-Example:
-
-        DENY_FILENAMES_PER_PATH(
-            qr:/src/:   => [qr/[^\w.-]/ => 'source files must be strict'],
-            qr:/doc/:   => qr/[^\w\s.-]/i, # document files allow spaces too.
-            qr:/notes/: => qr/^$/,         # notes directory allows anything.
-        );
-
-=cut
 
 my @Per_path_checks;		# per path restrictions
 
@@ -157,54 +90,95 @@ sub pre_commit {
     croak $errors if $errors;
 }
 
+1; # End of SVN::Hooks::DenyFilenames
+
+__END__
+=pod
+
+=head1 NAME
+
+SVN::Hooks::DenyFilenames - Deny some file names.
+
+=head1 VERSION
+
+version 1.12
+
+=head1 SYNOPSIS
+
+This SVN::Hooks plugin is used to disallow the addition of some file
+names.
+
+It's active in the C<pre-commit> hook.
+
+It's configured by the following directives.
+
+=head2 DENY_FILENAMES(REGEXP, [REGEXP => MESSAGE], ...)
+
+This directive denies the addition of new files matching the Regexps
+passed as arguments. If any file or directory added in the commit
+matches one of the specified Regexps the commit is aborted with an
+error message telling about every denied file.
+
+The arguments may be compiled Regexps or two-element arrays consisting
+of a compiled Regexp and a specific error message. If a file matches
+one of the lone Regexps an error message like this is produced:
+
+        DENY_FILENAMES: filename not allowed: filename
+
+If a file matches a Regexp associated with an error message, the
+specified error message is substituted for the 'filename not allowed'
+default.
+
+Note that this directive specifies a default restriction. If there are
+any B<DENY_FILENAMES_PER_PATH> directives (see below) being used, this
+one is only used for files that don't match any specific rules there.
+
+Example:
+
+        DENY_FILENAMES(
+            qr/\.(doc|xls|ppt)$/i, # ODF only, please
+            [qr/\.(exe|zip|jar)/i => 'No binaries, please!'],
+        );
+
+=head2 DENY_FILENAMES_PER_PATH(REGEXP => REGEXP, REGEXP => [REGEXP => MESSAGE], ...)
+
+This directive is more specific than the B<DENY_FILENAMES>, because it
+allows one to specify different restrictions in different regions of
+the repository tree.
+
+Its arguments are a sequence of rules, each one consisting of a
+pair. The first element of each pair is a regular expression
+specifying where in the repository this rule applies. It applies if
+any file being added matches the regexp. The second element specifies
+the restrictions that should be imposed, just like the arguments to
+B<DENY_FILENAMES>.
+
+The first rule matching an added file is used to check it. The
+following rules aren't tried.
+
+Only if no rules match a particular file will the restrictions defined
+by B<DENY_FILENAMES> be imposed.
+
+Example:
+
+        DENY_FILENAMES_PER_PATH(
+            qr:/src/:   => [qr/[^\w.-]/ => 'source files must be strict'],
+            qr:/doc/:   => qr/[^\w\s.-]/i, # document files allow spaces too.
+            qr:/notes/: => qr/^$/,         # notes directory allows anything.
+        );
+
+=for Pod::Coverage pre_commit
+
 =head1 AUTHOR
 
-Gustavo Chaves, C<< <gnustavo@cpan.org> >>
+Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-svn-hooks-denyfilenames at rt.cpan.org>, or through the web
-interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SVN-Hooks>.  I will
-be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+This software is copyright (c) 2012 by CPqD.
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc SVN::Hooks
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SVN-Hooks>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/SVN-Hooks>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/SVN-Hooks>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/SVN-Hooks>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 CPqD, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of SVN::Hooks::DenyFilenames
